/**
 * Core Services API
 * Use the Core Services API to manage resources such as virtual cloud networks (VCNs),
compute instances, and block storage volumes. For more information, see the console
documentation for the [Networking](https://docs.oracle.com/iaas/Content/Network/Concepts/overview.htm),
[Compute](https://docs.oracle.com/iaas/Content/Compute/Concepts/computeoverview.htm), and
[Block Volume](https://docs.oracle.com/iaas/Content/Block/Concepts/overview.htm) services.
The required permissions are documented in the
[Details for the Core Services](https://docs.oracle.com/iaas/Content/Identity/Reference/corepolicyreference.htm) article.

 * OpenAPI spec version: 20160918
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2025, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * The customer facing GPU memory cluster instance object details.
 *
 */
export interface ComputeGpuMemoryClusterInstanceSummary {
    /**
     * The availability domain of the GPU memory cluster instance.
     *
     */
    "availabilityDomain"?: string;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) for the Customer-unique GPU memory cluster instance
     *
     */
    "id"?: string;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) for the compartment
     * compartment.
     *
     */
    "compartmentId"?: string;
    /**
     * The fault domain the GPU memory cluster instance is running in.
     */
    "faultDomain"?: string;
    /**
     * Configuration to be used for this GPU Memory Cluster instance.
     *
     */
    "instanceConfigurationId"?: string;
    /**
     * The region that contains the availability domain the instance is running in.
     */
    "region"?: string;
    /**
     * The shape of an instance. The shape determines the number of CPUs, amount of memory,
     * and other resources allocated to the instance. The shape determines the number of CPUs,
     * the amount of memory, and other resources allocated to the instance.
     * You can list all available shapes by calling {@link #listShapes(ListShapesRequest) listShapes}.
     *
     */
    "instanceShape"?: string;
    /**
     * The lifecycle state of the GPU memory cluster instance
     *
     */
    "lifecycleState"?: ComputeGpuMemoryClusterInstanceSummary.LifecycleState;
    /**
     * A user-friendly name. Does not have to be unique, and it's changeable.
     * Avoid entering confidential information.
     *
     */
    "displayName"?: string;
    /**
      * The date and time the GPU memory cluster instance was created.
  * <p>
  Example: {@code 2016-09-15T21:10:29.600Z}
  *
      */
    "timeCreated"?: Date;
}
export declare namespace ComputeGpuMemoryClusterInstanceSummary {
    enum LifecycleState {
        Moving = "MOVING",
        Provisioning = "PROVISIONING",
        Running = "RUNNING",
        Starting = "STARTING",
        Stopping = "STOPPING",
        Stopped = "STOPPED",
        Suspending = "SUSPENDING",
        Suspended = "SUSPENDED",
        CreatingImage = "CREATING_IMAGE",
        Terminating = "TERMINATING",
        Terminated = "TERMINATED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: ComputeGpuMemoryClusterInstanceSummary): object;
    function getDeserializedJsonObj(obj: ComputeGpuMemoryClusterInstanceSummary): object;
}
