/**
 * Database Management API
 * Use the Database Management API to monitor and manage resources such as
Oracle Databases, MySQL Databases, and External Database Systems.
For more information, see [Database Management](https://docs.oracle.com/iaas/database-management/home.htm).

 * OpenAPI spec version: 20201101
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2025, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * The details of the backup metrics for a single database.
 */
export interface DatabaseBackupMetrics {
    /**
     * The retention period of the database.
     */
    "retentionPeriodInDays": string;
    /**
     * Indicates whether automatic backup is enabled or not. This is only applicable for cloud databases.
     */
    "isAutomaticBackupEnabled": boolean;
    /**
     * The array of metric values for different timestamps.
     */
    "timeSeriesMetrics": Array<model.MetricsAggregationRange>;
    /**
     * Indicates whether Data Guard is enabled for the database.
     */
    "isDataguardEnabled": boolean;
    "lastBackupSummary": model.DatabaseBackupSummary;
    /**
     * A list of database health metrics such as BackupDuration and BackupSize.
     */
    "metrics": Array<model.HaMetricDefinition>;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Managed Database.
     */
    "dbId": string;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment where the Managed Database resides.
     */
    "compartmentId": string;
    /**
     * The type of Oracle Database installation.
     */
    "databaseType": model.DatabaseType;
    /**
     * The subtype of the Oracle Database. Indicates whether the database is a Container Database,
     * Pluggable Database, Non-container Database, Autonomous Database, or Autonomous Container Database.
     *
     */
    "databaseSubType": model.DatabaseSubType;
    /**
     * The infrastructure used to deploy the Oracle Database.
     */
    "deploymentType": model.DeploymentType;
    /**
     * The Oracle Database version.
     */
    "databaseVersion"?: string;
    /**
     * The workload type of the Autonomous Database.
     */
    "workloadType"?: model.WorkloadType;
    /**
     * The display name of the Managed Database.
     */
    "databaseName": string;
    /**
     * The database ID of the Managed Database. Every database had its own ID and that value is captured here.
     */
    "databaseId"?: string;
    /**
     * The database unique name of the Managed Database.
     */
    "dbUniqueName"?: string;
    /**
     * The database role of the Managed Database.
     */
    "dbRole": model.DbRole;
}
export declare namespace DatabaseBackupMetrics {
    function getJsonObj(obj: DatabaseBackupMetrics): object;
    function getDeserializedJsonObj(obj: DatabaseBackupMetrics): object;
}
