/**
 * Oracle Delegate Access Control API
 * Oracle Delegate Access Control allows ExaCC and ExaCS customers to delegate management of their Exadata resources operators outside their tenancies.
With Delegate Access Control, Support Providers can deliver managed services using comprehensive and robust tooling built on the OCI platform.
Customers maintain control over who has access to the delegated resources in their tenancy and what actions can be taken.
Enterprises managing resources across multiple tenants can use Delegate Access Control to streamline management tasks.
Using logging service, customers can view a near real-time audit report of all actions performed by a Service Provider operator.

 * OpenAPI spec version: 20230801
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2025, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * Details of the Service Provider Action. Service provider actions are a pre-defined set of commands available to the support operator on different layers of the infrastructure. Although the groupings may differ depending on the infrastructure layers,
 * the groups are designed to enable the support operator access to commands to resolve a specific set of issues.
 *
 */
export interface ServiceProviderAction {
    /**
     * Unique Oracle assigned identifier for the Service Provider Action.
     */
    "id": string;
    /**
     * Unique name of the Service Provider Action.
     */
    "name": string;
    /**
     * Display Name of the Service Provider Action.
     */
    "customerDisplayName"?: string;
    /**
     * Name of the infrastructure layer associated with the Service Provider Action.
     */
    "component"?: string;
    /**
     * resourceType for which the ServiceProviderAction is applicable
     */
    "resourceType"?: model.DelegationControlResourceType;
    /**
     * List of Service Provider Service Types that this Service Provider Action is applicable to.
     */
    "serviceProviderServiceTypes"?: Array<ServiceProviderAction.ServiceProviderServiceTypes>;
    /**
     * The current lifecycle state of the Service Provider Action.
     */
    "lifecycleState"?: ServiceProviderAction.LifecycleState;
    /**
     * Description of the Service Provider Action in terms of associated risk profile, and characteristics of the operating system commands made
     * available to the support operator under this Service Provider Action.
     *
     */
    "description"?: string;
    /**
     * Fine grained properties associated with the Delegation Control.
     */
    "properties"?: Array<model.ServiceProviderActionProperties>;
}
export declare namespace ServiceProviderAction {
    enum ServiceProviderServiceTypes {
        Troubleshooting = "TROUBLESHOOTING",
        AssistedPatching = "ASSISTED_PATCHING",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum LifecycleState {
        Active = "ACTIVE",
        Inactive = "INACTIVE",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: ServiceProviderAction): object;
    function getDeserializedJsonObj(obj: ServiceProviderAction): object;
}
