/**
 * Full Stack Disaster Recovery API
 * Use the Full Stack Disaster Recovery (DR) API to manage disaster recovery for business applications.
Full Stack DR is an OCI disaster recovery orchestration and management service that provides comprehensive disaster
recovery capabilities for all layers of an application stack, including infrastructure, middleware, database,
and application.

 * OpenAPI spec version: 20220125
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2025, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * The details of backup performed on OKE Cluster.
 *
 */
export interface OkeClusterBackupConfig {
    /**
      * A list of namespaces that need to be backed up.
  * The default value is null. If a list of namespaces is not provided, all namespaces will be backed up.
  * This property applies to the OKE cluster member in primary region.
  * <p>
  Example: [\"default\", \"pv-nginx\"]
  *
      */
    "namespaces"?: Array<string>;
    /**
      * The schedule for backing up namespaces to the destination region. If a backup schedule is not specified, only a single backup will be created. This format of the string specifying the backup schedule must conform with RFC-5545.
  * This schedule will use the UTC timezone.
  * This property applies to the OKE cluster member in primary region.
  * <p>
  Example: FREQ=WEEKLY;BYDAY=MO,TU,WE,TH;BYHOUR=10;INTERVAL=1
  *
      */
    "backupSchedule"?: string;
    /**
     * Controls the behaviour of image replication across regions.
     * This property applies to the OKE cluster member in primary region.
     *
     */
    "replicateImages"?: model.OkeClusterImageReplication;
    /**
     * The maximum number of backups that should be retained.
     * This property applies to the OKE cluster member in primary region.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "maxNumberOfBackupsRetained"?: number;
    /**
     * The OCID of the vault secret that stores the image credential.
     * This property applies to the OKE cluster member in both the primary and standby region.
     *
     */
    "imageReplicationVaultSecretId"?: string;
}
export declare namespace OkeClusterBackupConfig {
    function getJsonObj(obj: OkeClusterBackupConfig): object;
    function getDeserializedJsonObj(obj: OkeClusterBackupConfig): object;
}
