/**
 * Fleet Application Management Service API
 * Fleet Application Management provides a centralized platform to help you automate resource management tasks, validate patch compliance, and enhance operational efficiency across an enterprise.

 * OpenAPI spec version: 20250228
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2025, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as responses from "./response";
import { FleetAppsManagementWaiter } from "./fleetappsmanagement-waiter";
import { FleetAppsManagementAdminWaiter } from "./fleetappsmanagementadmin-waiter";
import { FleetAppsManagementCatalogWaiter } from "./fleetappsmanagementcatalog-waiter";
import { FleetAppsManagementMaintenanceWindowWaiter } from "./fleetappsmanagementmaintenancewindow-waiter";
import { FleetAppsManagementOperationsWaiter } from "./fleetappsmanagementoperations-waiter";
import { FleetAppsManagementProvisionWaiter } from "./fleetappsmanagementprovision-waiter";
import { FleetAppsManagementRunbooksWaiter } from "./fleetappsmanagementrunbooks-waiter";
import { FleetAppsManagementWorkRequestWaiter } from "./fleetappsmanagementworkrequest-waiter";
declare const Breaker: any;
export declare enum FleetAppsManagementApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class FleetAppsManagementClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": FleetAppsManagementWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    protected _authProvider: common.AuthenticationDetailsProvider | undefined;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new FleetAppsManagementWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): FleetAppsManagementWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): FleetAppsManagementWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the provider if possible which in turn shuts down any associated circuit breaker
     */
    closeProvider(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Moves a Fleet into a different compartment within the same tenancy. For information about moving resources between
     * compartments, see [Moving Resources to a Different Compartment](https://docs.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeFleetCompartmentRequest
     * @return ChangeFleetCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/ChangeFleetCompartment.ts.html |here} to see how to use ChangeFleetCompartment API.
     */
    changeFleetCompartment(changeFleetCompartmentRequest: requests.ChangeFleetCompartmentRequest): Promise<responses.ChangeFleetCompartmentResponse>;
    /**
     * Check if Fleet Application Management tags can be added to the resources.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CheckResourceTaggingRequest
     * @return CheckResourceTaggingResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/CheckResourceTagging.ts.html |here} to see how to use CheckResourceTagging API.
     */
    checkResourceTagging(checkResourceTaggingRequest: requests.CheckResourceTaggingRequest): Promise<responses.CheckResourceTaggingResponse>;
    /**
     * Confirm targets to be managed for a Fleet.
     * Only targets that are confirmed will be managed by Fleet Application Management.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ConfirmTargetsRequest
     * @return ConfirmTargetsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/ConfirmTargets.ts.html |here} to see how to use ConfirmTargets API.
     */
    confirmTargets(confirmTargetsRequest: requests.ConfirmTargetsRequest): Promise<responses.ConfirmTargetsResponse>;
    /**
     * Create a fleet in Fleet Application Management.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateFleetRequest
     * @return CreateFleetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/CreateFleet.ts.html |here} to see how to use CreateFleet API.
     */
    createFleet(createFleetRequest: requests.CreateFleetRequest): Promise<responses.CreateFleetResponse>;
    /**
     * Add credentials to a fleet in Fleet Application Management.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateFleetCredentialRequest
     * @return CreateFleetCredentialResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/CreateFleetCredential.ts.html |here} to see how to use CreateFleetCredential API.
     */
    createFleetCredential(createFleetCredentialRequest: requests.CreateFleetCredentialRequest): Promise<responses.CreateFleetCredentialResponse>;
    /**
     * Add an existing global property to a fleet in Fleet Application Management.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateFleetPropertyRequest
     * @return CreateFleetPropertyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/CreateFleetProperty.ts.html |here} to see how to use CreateFleetProperty API.
     */
    createFleetProperty(createFleetPropertyRequest: requests.CreateFleetPropertyRequest): Promise<responses.CreateFleetPropertyResponse>;
    /**
     * Add resource to a fleet in Fleet Application Management.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateFleetResourceRequest
     * @return CreateFleetResourceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/CreateFleetResource.ts.html |here} to see how to use CreateFleetResource API.
     */
    createFleetResource(createFleetResourceRequest: requests.CreateFleetResourceRequest): Promise<responses.CreateFleetResourceResponse>;
    /**
     * Delete a fleet in Fleet Application Management.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteFleetRequest
     * @return DeleteFleetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/DeleteFleet.ts.html |here} to see how to use DeleteFleet API.
     */
    deleteFleet(deleteFleetRequest: requests.DeleteFleetRequest): Promise<responses.DeleteFleetResponse>;
    /**
     * Deletes a credential associated with a fleet or with a product/target with in a fleet.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteFleetCredentialRequest
     * @return DeleteFleetCredentialResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/DeleteFleetCredential.ts.html |here} to see how to use DeleteFleetCredential API.
     */
    deleteFleetCredential(deleteFleetCredentialRequest: requests.DeleteFleetCredentialRequest): Promise<responses.DeleteFleetCredentialResponse>;
    /**
     * Deletes a property associated with a fleet in Fleet Application Management.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteFleetPropertyRequest
     * @return DeleteFleetPropertyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/DeleteFleetProperty.ts.html |here} to see how to use DeleteFleetProperty API.
     */
    deleteFleetProperty(deleteFleetPropertyRequest: requests.DeleteFleetPropertyRequest): Promise<responses.DeleteFleetPropertyResponse>;
    /**
     * Removes a resource from the fleet in Fleet Application Management.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteFleetResourceRequest
     * @return DeleteFleetResourceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/DeleteFleetResource.ts.html |here} to see how to use DeleteFleetResource API.
     */
    deleteFleetResource(deleteFleetResourceRequest: requests.DeleteFleetResourceRequest): Promise<responses.DeleteFleetResourceResponse>;
    /**
     * Generate compliance report for a Fleet.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GenerateComplianceReportRequest
     * @return GenerateComplianceReportResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/GenerateComplianceReport.ts.html |here} to see how to use GenerateComplianceReport API.
     */
    generateComplianceReport(generateComplianceReportRequest: requests.GenerateComplianceReportRequest): Promise<responses.GenerateComplianceReportResponse>;
    /**
     * Retrieve compliance report for a fleet.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetComplianceReportRequest
     * @return GetComplianceReportResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/GetComplianceReport.ts.html |here} to see how to use GetComplianceReport API.
     */
    getComplianceReport(getComplianceReportRequest: requests.GetComplianceReportRequest): Promise<responses.GetComplianceReportResponse>;
    /**
     * Get the details of a fleet in Fleet Application Management.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetFleetRequest
     * @return GetFleetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/GetFleet.ts.html |here} to see how to use GetFleet API.
     */
    getFleet(getFleetRequest: requests.GetFleetRequest): Promise<responses.GetFleetResponse>;
    /**
     * Gets a fleet credential by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetFleetCredentialRequest
     * @return GetFleetCredentialResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/GetFleetCredential.ts.html |here} to see how to use GetFleetCredential API.
     */
    getFleetCredential(getFleetCredentialRequest: requests.GetFleetCredentialRequest): Promise<responses.GetFleetCredentialResponse>;
    /**
     * Gets a fleet property by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetFleetPropertyRequest
     * @return GetFleetPropertyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/GetFleetProperty.ts.html |here} to see how to use GetFleetProperty API.
     */
    getFleetProperty(getFleetPropertyRequest: requests.GetFleetPropertyRequest): Promise<responses.GetFleetPropertyResponse>;
    /**
     * Gets a fleet resource by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetFleetResourceRequest
     * @return GetFleetResourceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/GetFleetResource.ts.html |here} to see how to use GetFleetResource API.
     */
    getFleetResource(getFleetResourceRequest: requests.GetFleetResourceRequest): Promise<responses.GetFleetResourceResponse>;
    /**
     * Return a list of Announcement Summary items in a tenancy.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListAnnouncementsRequest
     * @return ListAnnouncementsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/ListAnnouncements.ts.html |here} to see how to use ListAnnouncements API.
     */
    listAnnouncements(listAnnouncementsRequest: requests.ListAnnouncementsRequest): Promise<responses.ListAnnouncementsResponse>;
    /**
     * List credentials associated with a fleet.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListFleetCredentialsRequest
     * @return ListFleetCredentialsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/ListFleetCredentials.ts.html |here} to see how to use ListFleetCredentials API.
     */
    listFleetCredentials(listFleetCredentialsRequest: requests.ListFleetCredentialsRequest): Promise<responses.ListFleetCredentialsResponse>;
    /**
     * Returns a list of products associated with the confirmed targets.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListFleetProductsRequest
     * @return ListFleetProductsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/ListFleetProducts.ts.html |here} to see how to use ListFleetProducts API.
     */
    listFleetProducts(listFleetProductsRequest: requests.ListFleetProductsRequest): Promise<responses.ListFleetProductsResponse>;
    /**
     * List properties associated with a fleet.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListFleetPropertiesRequest
     * @return ListFleetPropertiesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/ListFleetProperties.ts.html |here} to see how to use ListFleetProperties API.
     */
    listFleetProperties(listFleetPropertiesRequest: requests.ListFleetPropertiesRequest): Promise<responses.ListFleetPropertiesResponse>;
    /**
     * List resources for a fleet in Fleet Application Management.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListFleetResourcesRequest
     * @return ListFleetResourcesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/ListFleetResources.ts.html |here} to see how to use ListFleetResources API.
     */
    listFleetResources(listFleetResourcesRequest: requests.ListFleetResourcesRequest): Promise<responses.ListFleetResourcesResponse>;
    /**
     * Returns the list of all confirmed targets within a fleet.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListFleetTargetsRequest
     * @return ListFleetTargetsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/ListFleetTargets.ts.html |here} to see how to use ListFleetTargets API.
     */
    listFleetTargets(listFleetTargetsRequest: requests.ListFleetTargetsRequest): Promise<responses.ListFleetTargetsResponse>;
    /**
     * Returns a list of all the Fleets in the specified compartment.
     * The query parameter `compartmentId` is required unless the query parameter `id` is specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListFleetsRequest
     * @return ListFleetsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/ListFleets.ts.html |here} to see how to use ListFleets API.
     */
    listFleets(listFleetsRequest: requests.ListFleetsRequest): Promise<responses.ListFleetsResponse>;
    /**
     * Returns a list of Inventory Resources based on the criteria provided.
     * instance, dbsystem, cloudvmcluster resources are supported.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListInventoryResourcesRequest
     * @return ListInventoryResourcesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/ListInventoryResources.ts.html |here} to see how to use ListInventoryResources API.
     */
    listInventoryResources(listInventoryResourcesRequest: requests.ListInventoryResourcesRequest): Promise<responses.ListInventoryResourcesResponse>;
    /**
     * Return all targets belonging to the resources within a fleet.
     * It will include both confirmed and unconfirmed targets.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListTargetsRequest
     * @return ListTargetsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/ListTargets.ts.html |here} to see how to use ListTargets API.
     */
    listTargets(listTargetsRequest: requests.ListTargetsRequest): Promise<responses.ListTargetsResponse>;
    /**
     * Request validation for resources within a fleet.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param RequestResourceValidationRequest
     * @return RequestResourceValidationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/RequestResourceValidation.ts.html |here} to see how to use RequestResourceValidation API.
     */
    requestResourceValidation(requestResourceValidationRequest: requests.RequestResourceValidationRequest): Promise<responses.RequestResourceValidationResponse>;
    /**
     * Request target discovery for resources with in a fleet.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param RequestTargetDiscoveryRequest
     * @return RequestTargetDiscoveryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/RequestTargetDiscovery.ts.html |here} to see how to use RequestTargetDiscovery API.
     */
    requestTargetDiscovery(requestTargetDiscoveryRequest: requests.RequestTargetDiscoveryRequest): Promise<responses.RequestTargetDiscoveryResponse>;
    /**
     * Update fleet information in Fleet Application Management.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateFleetRequest
     * @return UpdateFleetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/UpdateFleet.ts.html |here} to see how to use UpdateFleet API.
     */
    updateFleet(updateFleetRequest: requests.UpdateFleetRequest): Promise<responses.UpdateFleetResponse>;
    /**
     * Edit credential associated with a fleet or with a product/target with in a fleet.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateFleetCredentialRequest
     * @return UpdateFleetCredentialResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/UpdateFleetCredential.ts.html |here} to see how to use UpdateFleetCredential API.
     */
    updateFleetCredential(updateFleetCredentialRequest: requests.UpdateFleetCredentialRequest): Promise<responses.UpdateFleetCredentialResponse>;
    /**
     * Edit a property associated with a fleet in Fleet Application Management.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateFleetPropertyRequest
     * @return UpdateFleetPropertyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/UpdateFleetProperty.ts.html |here} to see how to use UpdateFleetProperty API.
     */
    updateFleetProperty(updateFleetPropertyRequest: requests.UpdateFleetPropertyRequest): Promise<responses.UpdateFleetPropertyResponse>;
    /**
     * Updates the FleetResource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateFleetResourceRequest
     * @return UpdateFleetResourceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/UpdateFleetResource.ts.html |here} to see how to use UpdateFleetResource API.
     */
    updateFleetResource(updateFleetResourceRequest: requests.UpdateFleetResourceRequest): Promise<responses.UpdateFleetResourceResponse>;
}
export declare enum FleetAppsManagementAdminApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class FleetAppsManagementAdminClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": FleetAppsManagementAdminWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    protected _authProvider: common.AuthenticationDetailsProvider | undefined;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new FleetAppsManagementAdminWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): FleetAppsManagementAdminWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): FleetAppsManagementAdminWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the provider if possible which in turn shuts down any associated circuit breaker
     */
    closeProvider(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Moves a PlatformConfiguration into a different compartment within the same tenancy. For information about moving resources between
     * compartments, see [Moving Resources to a Different Compartment](https://docs.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangePlatformConfigurationCompartmentRequest
     * @return ChangePlatformConfigurationCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/ChangePlatformConfigurationCompartment.ts.html |here} to see how to use ChangePlatformConfigurationCompartment API.
     */
    changePlatformConfigurationCompartment(changePlatformConfigurationCompartmentRequest: requests.ChangePlatformConfigurationCompartmentRequest): Promise<responses.ChangePlatformConfigurationCompartmentResponse>;
    /**
     * Moves a Property into a different compartment within the same tenancy. For information about moving resources between
     * compartments, see [Moving Resources to a Different Compartment](https://docs.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangePropertyCompartmentRequest
     * @return ChangePropertyCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/ChangePropertyCompartment.ts.html |here} to see how to use ChangePropertyCompartment API.
     */
    changePropertyCompartment(changePropertyCompartmentRequest: requests.ChangePropertyCompartmentRequest): Promise<responses.ChangePropertyCompartmentResponse>;
    /**
     * Creates a compliance policy rule.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateCompliancePolicyRuleRequest
     * @return CreateCompliancePolicyRuleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/CreateCompliancePolicyRule.ts.html |here} to see how to use CreateCompliancePolicyRule API.
     */
    createCompliancePolicyRule(createCompliancePolicyRuleRequest: requests.CreateCompliancePolicyRuleRequest): Promise<responses.CreateCompliancePolicyRuleResponse>;
    /**
     * Onboard a tenant to Fleet Application Management.
     * The onboarding process lets Fleet Application Management create a few required policies that you need to start using it and its features.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateOnboardingRequest
     * @return CreateOnboardingResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/CreateOnboarding.ts.html |here} to see how to use CreateOnboarding API.
     */
    createOnboarding(createOnboardingRequest: requests.CreateOnboardingRequest): Promise<responses.CreateOnboardingResponse>;
    /**
     * Creates a new PlatformConfiguration.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreatePlatformConfigurationRequest
     * @return CreatePlatformConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/CreatePlatformConfiguration.ts.html |here} to see how to use CreatePlatformConfiguration API.
     */
    createPlatformConfiguration(createPlatformConfigurationRequest: requests.CreatePlatformConfigurationRequest): Promise<responses.CreatePlatformConfigurationResponse>;
    /**
     * Create a business-specific metadata property in Fleet Application Management.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreatePropertyRequest
     * @return CreatePropertyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/CreateProperty.ts.html |here} to see how to use CreateProperty API.
     */
    createProperty(createPropertyRequest: requests.CreatePropertyRequest): Promise<responses.CreatePropertyResponse>;
    /**
     * Deletes a compliance policy rule specified by an identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteCompliancePolicyRuleRequest
     * @return DeleteCompliancePolicyRuleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/DeleteCompliancePolicyRule.ts.html |here} to see how to use DeleteCompliancePolicyRule API.
     */
    deleteCompliancePolicyRule(deleteCompliancePolicyRuleRequest: requests.DeleteCompliancePolicyRuleRequest): Promise<responses.DeleteCompliancePolicyRuleResponse>;
    /**
     * Deletes Fleet Application Management onboarding resource by identifier
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteOnboardingRequest
     * @return DeleteOnboardingResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/DeleteOnboarding.ts.html |here} to see how to use DeleteOnboarding API.
     */
    deleteOnboarding(deleteOnboardingRequest: requests.DeleteOnboardingRequest): Promise<responses.DeleteOnboardingResponse>;
    /**
     * Deletes a PlatformConfiguration resource by identifier
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeletePlatformConfigurationRequest
     * @return DeletePlatformConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/DeletePlatformConfiguration.ts.html |here} to see how to use DeletePlatformConfiguration API.
     */
    deletePlatformConfiguration(deletePlatformConfigurationRequest: requests.DeletePlatformConfigurationRequest): Promise<responses.DeletePlatformConfigurationResponse>;
    /**
     * Delete a property in Fleet Application Management.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeletePropertyRequest
     * @return DeletePropertyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/DeleteProperty.ts.html |here} to see how to use DeleteProperty API.
     */
    deleteProperty(deletePropertyRequest: requests.DeletePropertyRequest): Promise<responses.DeletePropertyResponse>;
    /**
     * Enable Policies for a newer version of Fleet Application Management
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param EnableLatestPolicyRequest
     * @return EnableLatestPolicyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/EnableLatestPolicy.ts.html |here} to see how to use EnableLatestPolicy API.
     */
    enableLatestPolicy(enableLatestPolicyRequest: requests.EnableLatestPolicyRequest): Promise<responses.EnableLatestPolicyResponse>;
    /**
     * Gets information about a compliance policy.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetCompliancePolicyRequest
     * @return GetCompliancePolicyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/GetCompliancePolicy.ts.html |here} to see how to use GetCompliancePolicy API.
     */
    getCompliancePolicy(getCompliancePolicyRequest: requests.GetCompliancePolicyRequest): Promise<responses.GetCompliancePolicyResponse>;
    /**
     * Gets information about a compliance policy rule.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetCompliancePolicyRuleRequest
     * @return GetCompliancePolicyRuleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/GetCompliancePolicyRule.ts.html |here} to see how to use GetCompliancePolicyRule API.
     */
    getCompliancePolicyRule(getCompliancePolicyRuleRequest: requests.GetCompliancePolicyRuleRequest): Promise<responses.GetCompliancePolicyRuleResponse>;
    /**
     * Gets a Fleet Application Management Onboarding by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetOnboardingRequest
     * @return GetOnboardingResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/GetOnboarding.ts.html |here} to see how to use GetOnboarding API.
     */
    getOnboarding(getOnboardingRequest: requests.GetOnboardingRequest): Promise<responses.GetOnboardingResponse>;
    /**
     * Gets a PlatformConfiguration by identifier
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetPlatformConfigurationRequest
     * @return GetPlatformConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/GetPlatformConfiguration.ts.html |here} to see how to use GetPlatformConfiguration API.
     */
    getPlatformConfiguration(getPlatformConfigurationRequest: requests.GetPlatformConfigurationRequest): Promise<responses.GetPlatformConfigurationResponse>;
    /**
     * Gets a Property by identifier
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetPropertyRequest
     * @return GetPropertyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/GetProperty.ts.html |here} to see how to use GetProperty API.
     */
    getProperty(getPropertyRequest: requests.GetPropertyRequest): Promise<responses.GetPropertyResponse>;
    /**
     * Returns a list of all the Compliance Policies in the specified compartment.
     * The query parameter `compartmentId` is required unless the query parameter `id` is specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListCompliancePoliciesRequest
     * @return ListCompliancePoliciesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/ListCompliancePolicies.ts.html |here} to see how to use ListCompliancePolicies API.
     */
    listCompliancePolicies(listCompliancePoliciesRequest: requests.ListCompliancePoliciesRequest): Promise<responses.ListCompliancePoliciesResponse>;
    /**
     * Gets a list of Compliance policy rules in a compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListCompliancePolicyRulesRequest
     * @return ListCompliancePolicyRulesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/ListCompliancePolicyRules.ts.html |here} to see how to use ListCompliancePolicyRules API.
     */
    listCompliancePolicyRules(listCompliancePolicyRulesRequest: requests.ListCompliancePolicyRulesRequest): Promise<responses.ListCompliancePolicyRulesResponse>;
    /**
     * Returns a list of onboarding policy information for Fleet Application Management.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListOnboardingPoliciesRequest
     * @return ListOnboardingPoliciesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/ListOnboardingPolicies.ts.html |here} to see how to use ListOnboardingPolicies API.
     */
    listOnboardingPolicies(listOnboardingPoliciesRequest: requests.ListOnboardingPoliciesRequest): Promise<responses.ListOnboardingPoliciesResponse>;
    /**
     * Returns a list of all the onboardings in the specified root compartment (tenancy).
     * The query parameter `compartmentId` is required unless the query parameter `id` is specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListOnboardingsRequest
     * @return ListOnboardingsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/ListOnboardings.ts.html |here} to see how to use ListOnboardings API.
     */
    listOnboardings(listOnboardingsRequest: requests.ListOnboardingsRequest): Promise<responses.ListOnboardingsResponse>;
    /**
     * Returns a list of all the Platform Configurations in the specified compartment.
     * The query parameter `compartmentId` is required unless the query parameter `id` is specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListPlatformConfigurationsRequest
     * @return ListPlatformConfigurationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/ListPlatformConfigurations.ts.html |here} to see how to use ListPlatformConfigurations API.
     */
    listPlatformConfigurations(listPlatformConfigurationsRequest: requests.ListPlatformConfigurationsRequest): Promise<responses.ListPlatformConfigurationsResponse>;
    /**
     * Returns a list of all the Properties in the specified compartment.
     * The query parameter `compartmentId` is required unless the query parameter `id` is specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListPropertiesRequest
     * @return ListPropertiesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/ListProperties.ts.html |here} to see how to use ListProperties API.
     */
    listProperties(listPropertiesRequest: requests.ListPropertiesRequest): Promise<responses.ListPropertiesResponse>;
    /**
     * Updates the Onboarding setting
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ManageSettingsRequest
     * @return ManageSettingsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/ManageSettings.ts.html |here} to see how to use ManageSettings API.
     */
    manageSettings(manageSettingsRequest: requests.ManageSettingsRequest): Promise<responses.ManageSettingsResponse>;
    /**
     * Updates a compliance policy rule specified by an identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateCompliancePolicyRuleRequest
     * @return UpdateCompliancePolicyRuleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/UpdateCompliancePolicyRule.ts.html |here} to see how to use UpdateCompliancePolicyRule API.
     */
    updateCompliancePolicyRule(updateCompliancePolicyRuleRequest: requests.UpdateCompliancePolicyRuleRequest): Promise<responses.UpdateCompliancePolicyRuleResponse>;
    /**
     * Updates the Onboarding
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateOnboardingRequest
     * @return UpdateOnboardingResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/UpdateOnboarding.ts.html |here} to see how to use UpdateOnboarding API.
     */
    updateOnboarding(updateOnboardingRequest: requests.UpdateOnboardingRequest): Promise<responses.UpdateOnboardingResponse>;
    /**
     * Updates the PlatformConfiguration
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdatePlatformConfigurationRequest
     * @return UpdatePlatformConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/UpdatePlatformConfiguration.ts.html |here} to see how to use UpdatePlatformConfiguration API.
     */
    updatePlatformConfiguration(updatePlatformConfigurationRequest: requests.UpdatePlatformConfigurationRequest): Promise<responses.UpdatePlatformConfigurationResponse>;
    /**
     * Update a property in Fleet Application Management.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdatePropertyRequest
     * @return UpdatePropertyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/UpdateProperty.ts.html |here} to see how to use UpdateProperty API.
     */
    updateProperty(updatePropertyRequest: requests.UpdatePropertyRequest): Promise<responses.UpdatePropertyResponse>;
}
export declare enum FleetAppsManagementCatalogApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class FleetAppsManagementCatalogClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": FleetAppsManagementCatalogWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    protected _authProvider: common.AuthenticationDetailsProvider | undefined;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new FleetAppsManagementCatalogWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): FleetAppsManagementCatalogWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): FleetAppsManagementCatalogWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the provider if possible which in turn shuts down any associated circuit breaker
     */
    closeProvider(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Moves a CatalogItem into a different compartment within the same tenancy. For information about moving resources between
     * compartments, see [Moving Resources to a Different Compartment](https://docs.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeCatalogItemCompartmentRequest
     * @return ChangeCatalogItemCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/ChangeCatalogItemCompartment.ts.html |here} to see how to use ChangeCatalogItemCompartment API.
     */
    changeCatalogItemCompartment(changeCatalogItemCompartmentRequest: requests.ChangeCatalogItemCompartmentRequest): Promise<responses.ChangeCatalogItemCompartmentResponse>;
    /**
     * Clones a CatalogItem into a different compartment within the same tenancy. For information about moving resources between
     * compartments, see [Moving Resources to a Different Compartment](https://docs.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CloneCatalogItemRequest
     * @return CloneCatalogItemResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/CloneCatalogItem.ts.html |here} to see how to use CloneCatalogItem API.
     */
    cloneCatalogItem(cloneCatalogItemRequest: requests.CloneCatalogItemRequest): Promise<responses.CloneCatalogItemResponse>;
    /**
     * Creates a CatalogItem.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateCatalogItemRequest
     * @return CreateCatalogItemResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/CreateCatalogItem.ts.html |here} to see how to use CreateCatalogItem API.
     */
    createCatalogItem(createCatalogItemRequest: requests.CreateCatalogItemRequest): Promise<responses.CreateCatalogItemResponse>;
    /**
     * Deletes a CatalogItem.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteCatalogItemRequest
     * @return DeleteCatalogItemResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/DeleteCatalogItem.ts.html |here} to see how to use DeleteCatalogItem API.
     */
    deleteCatalogItem(deleteCatalogItemRequest: requests.DeleteCatalogItemRequest): Promise<responses.DeleteCatalogItemResponse>;
    /**
     * Gets information about a CatalogItem.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetCatalogItemRequest
     * @return GetCatalogItemResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/GetCatalogItem.ts.html |here} to see how to use GetCatalogItem API.
     */
    getCatalogItem(getCatalogItemRequest: requests.GetCatalogItemRequest): Promise<responses.GetCatalogItemResponse>;
    /**
     * Gets a list of Catalog Items in a compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListCatalogItemsRequest
     * @return ListCatalogItemsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/ListCatalogItems.ts.html |here} to see how to use ListCatalogItems API.
     */
    listCatalogItems(listCatalogItemsRequest: requests.ListCatalogItemsRequest): Promise<responses.ListCatalogItemsResponse>;
    /**
     * Updates a CatalogItem.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateCatalogItemRequest
     * @return UpdateCatalogItemResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/UpdateCatalogItem.ts.html |here} to see how to use UpdateCatalogItem API.
     */
    updateCatalogItem(updateCatalogItemRequest: requests.UpdateCatalogItemRequest): Promise<responses.UpdateCatalogItemResponse>;
}
export declare enum FleetAppsManagementMaintenanceWindowApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class FleetAppsManagementMaintenanceWindowClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": FleetAppsManagementMaintenanceWindowWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    protected _authProvider: common.AuthenticationDetailsProvider | undefined;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new FleetAppsManagementMaintenanceWindowWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): FleetAppsManagementMaintenanceWindowWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): FleetAppsManagementMaintenanceWindowWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the provider if possible which in turn shuts down any associated circuit breaker
     */
    closeProvider(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Create a maintenance window in Fleet Application Management.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateMaintenanceWindowRequest
     * @return CreateMaintenanceWindowResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/CreateMaintenanceWindow.ts.html |here} to see how to use CreateMaintenanceWindow API.
     */
    createMaintenanceWindow(createMaintenanceWindowRequest: requests.CreateMaintenanceWindowRequest): Promise<responses.CreateMaintenanceWindowResponse>;
    /**
     * Delete a maintenance window in Fleet Application Management.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteMaintenanceWindowRequest
     * @return DeleteMaintenanceWindowResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/DeleteMaintenanceWindow.ts.html |here} to see how to use DeleteMaintenanceWindow API.
     */
    deleteMaintenanceWindow(deleteMaintenanceWindowRequest: requests.DeleteMaintenanceWindowRequest): Promise<responses.DeleteMaintenanceWindowResponse>;
    /**
     * Get the details for a maintenance window in Fleet Application Management.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetMaintenanceWindowRequest
     * @return GetMaintenanceWindowResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/GetMaintenanceWindow.ts.html |here} to see how to use GetMaintenanceWindow API.
     */
    getMaintenanceWindow(getMaintenanceWindowRequest: requests.GetMaintenanceWindowRequest): Promise<responses.GetMaintenanceWindowResponse>;
    /**
     * Returns a list of all the Maintenance Windows in the specified compartment.
     * The query parameter `compartmentId` is required unless the query parameter `id` is specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListMaintenanceWindowsRequest
     * @return ListMaintenanceWindowsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/ListMaintenanceWindows.ts.html |here} to see how to use ListMaintenanceWindows API.
     */
    listMaintenanceWindows(listMaintenanceWindowsRequest: requests.ListMaintenanceWindowsRequest): Promise<responses.ListMaintenanceWindowsResponse>;
    /**
     * Update a maintenance window in Fleet Application Management.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateMaintenanceWindowRequest
     * @return UpdateMaintenanceWindowResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/UpdateMaintenanceWindow.ts.html |here} to see how to use UpdateMaintenanceWindow API.
     */
    updateMaintenanceWindow(updateMaintenanceWindowRequest: requests.UpdateMaintenanceWindowRequest): Promise<responses.UpdateMaintenanceWindowResponse>;
}
export declare enum FleetAppsManagementOperationsApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class FleetAppsManagementOperationsClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": FleetAppsManagementOperationsWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    protected _authProvider: common.AuthenticationDetailsProvider | undefined;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new FleetAppsManagementOperationsWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): FleetAppsManagementOperationsWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): FleetAppsManagementOperationsWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the provider if possible which in turn shuts down any associated circuit breaker
     */
    closeProvider(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Moves a Patch into a different compartment within the same tenancy. For information about moving resources between
     * compartments, see [Moving Resources to a Different Compartment](https://docs.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangePatchCompartmentRequest
     * @return ChangePatchCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/ChangePatchCompartment.ts.html |here} to see how to use ChangePatchCompartment API.
     */
    changePatchCompartment(changePatchCompartmentRequest: requests.ChangePatchCompartmentRequest): Promise<responses.ChangePatchCompartmentResponse>;
    /**
     * Creates a new Patch.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreatePatchRequest
     * @return CreatePatchResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/CreatePatch.ts.html |here} to see how to use CreatePatch API.
     */
    createPatch(createPatchRequest: requests.CreatePatchRequest): Promise<responses.CreatePatchResponse>;
    /**
     * Create a SchedulerDefinition to perform lifecycle operations.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateSchedulerDefinitionRequest
     * @return CreateSchedulerDefinitionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/CreateSchedulerDefinition.ts.html |here} to see how to use CreateSchedulerDefinition API.
     */
    createSchedulerDefinition(createSchedulerDefinitionRequest: requests.CreateSchedulerDefinitionRequest): Promise<responses.CreateSchedulerDefinitionResponse>;
    /**
     * Deletes the patch specified by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeletePatchRequest
     * @return DeletePatchResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/DeletePatch.ts.html |here} to see how to use DeletePatch API.
     */
    deletePatch(deletePatchRequest: requests.DeletePatchRequest): Promise<responses.DeletePatchResponse>;
    /**
     * Deletes a SchedulerDefinition resource by identifier
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteSchedulerDefinitionRequest
     * @return DeleteSchedulerDefinitionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/DeleteSchedulerDefinition.ts.html |here} to see how to use DeleteSchedulerDefinition API.
     */
    deleteSchedulerDefinition(deleteSchedulerDefinitionRequest: requests.DeleteSchedulerDefinitionRequest): Promise<responses.DeleteSchedulerDefinitionResponse>;
    /**
     * Deletes the schedule job specified by an identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteSchedulerJobRequest
     * @return DeleteSchedulerJobResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/DeleteSchedulerJob.ts.html |here} to see how to use DeleteSchedulerJob API.
     */
    deleteSchedulerJob(deleteSchedulerJobRequest: requests.DeleteSchedulerJobRequest): Promise<responses.DeleteSchedulerJobResponse>;
    /**
     * Generate Compliance Report
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ExportComplianceReportRequest
     * @return ExportComplianceReportResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/ExportComplianceReport.ts.html |here} to see how to use ExportComplianceReport API.
     */
    exportComplianceReport(exportComplianceReportRequest: requests.ExportComplianceReportRequest): Promise<responses.ExportComplianceReportResponse>;
    /**
     * Get Task Execution by Identifier for a Resource within an action group.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetExecutionRequest
     * @return GetExecutionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/GetExecution.ts.html |here} to see how to use GetExecution API.
     */
    getExecution(getExecutionRequest: requests.GetExecutionRequest): Promise<responses.GetExecutionResponse>;
    /**
     * Gets activity details by identifier for a job.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetJobActivityRequest
     * @return GetJobActivityResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/GetJobActivity.ts.html |here} to see how to use GetJobActivity API.
     */
    getJobActivity(getJobActivityRequest: requests.GetJobActivityRequest): Promise<responses.GetJobActivityResponse>;
    /**
     * Gets a Patch by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetPatchRequest
     * @return GetPatchResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/GetPatch.ts.html |here} to see how to use GetPatch API.
     */
    getPatch(getPatchRequest: requests.GetPatchRequest): Promise<responses.GetPatchResponse>;
    /**
     * Get the details of a SchedulerDefinition that performs lifecycle management operations.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetSchedulerDefinitionRequest
     * @return GetSchedulerDefinitionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/GetSchedulerDefinition.ts.html |here} to see how to use GetSchedulerDefinition API.
     */
    getSchedulerDefinition(getSchedulerDefinitionRequest: requests.GetSchedulerDefinitionRequest): Promise<responses.GetSchedulerDefinitionResponse>;
    /**
     * Get the details of a lifecycle management operations job in Fleet Application Management.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetSchedulerJobRequest
     * @return GetSchedulerJobResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/GetSchedulerJob.ts.html |here} to see how to use GetSchedulerJob API.
     */
    getSchedulerJob(getSchedulerJobRequest: requests.GetSchedulerJobRequest): Promise<responses.GetSchedulerJobResponse>;
    /**
     * Gets a list of complianceDetails.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListComplianceRecordsRequest
     * @return ListComplianceRecordsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/ListComplianceRecords.ts.html |here} to see how to use ListComplianceRecords API.
     */
    listComplianceRecords(listComplianceRecordsRequest: requests.ListComplianceRecordsRequest): Promise<responses.ListComplianceRecordsResponse>;
    /**
     * Returns a list of Task Executions for a Resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListExecutionsRequest
     * @return ListExecutionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/ListExecutions.ts.html |here} to see how to use ListExecutions API.
     */
    listExecutions(listExecutionsRequest: requests.ListExecutionsRequest): Promise<responses.ListExecutionsResponse>;
    /**
     * Gets a list of inventoryDetails.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListInventoryRecordsRequest
     * @return ListInventoryRecordsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/ListInventoryRecords.ts.html |here} to see how to use ListInventoryRecords API.
     */
    listInventoryRecords(listInventoryRecordsRequest: requests.ListInventoryRecordsRequest): Promise<responses.ListInventoryRecordsResponse>;
    /**
     * Returns a list of all the Patches in the specified compartment.
     * The query parameter `compartmentId` is required unless the query parameter `id` is specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListPatchesRequest
     * @return ListPatchesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/ListPatches.ts.html |here} to see how to use ListPatches API.
     */
    listPatches(listPatchesRequest: requests.ListPatchesRequest): Promise<responses.ListPatchesResponse>;
    /**
     * Returns a list of resources for an Activity Execution.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListResourcesRequest
     * @return ListResourcesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/ListResources.ts.html |here} to see how to use ListResources API.
     */
    listResources(listResourcesRequest: requests.ListResourcesRequest): Promise<responses.ListResourcesResponse>;
    /**
     * Returns a list of ScheduledFleets.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListScheduledFleetsRequest
     * @return ListScheduledFleetsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/ListScheduledFleets.ts.html |here} to see how to use ListScheduledFleets API.
     */
    listScheduledFleets(listScheduledFleetsRequest: requests.ListScheduledFleetsRequest): Promise<responses.ListScheduledFleetsResponse>;
    /**
     * Returns a list of all the Schedule Definitions in the specified compartment.
     * The query parameter `compartmentId` is required unless the query parameter `id` is specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListSchedulerDefinitionsRequest
     * @return ListSchedulerDefinitionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/ListSchedulerDefinitions.ts.html |here} to see how to use ListSchedulerDefinitions API.
     */
    listSchedulerDefinitions(listSchedulerDefinitionsRequest: requests.ListSchedulerDefinitionsRequest): Promise<responses.ListSchedulerDefinitionsResponse>;
    /**
     * Returns a list of all Fleets that are scheduled.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListSchedulerExecutionsRequest
     * @return ListSchedulerExecutionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/ListSchedulerExecutions.ts.html |here} to see how to use ListSchedulerExecutions API.
     */
    listSchedulerExecutions(listSchedulerExecutionsRequest: requests.ListSchedulerExecutionsRequest): Promise<responses.ListSchedulerExecutionsResponse>;
    /**
     * Returns a list of all schedule jobs in the specified compartment.
     * The query parameter `compartmentId` is required unless the query parameter `id` is specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListSchedulerJobsRequest
     * @return ListSchedulerJobsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/ListSchedulerJobs.ts.html |here} to see how to use ListSchedulerJobs API.
     */
    listSchedulerJobs(listSchedulerJobsRequest: requests.ListSchedulerJobsRequest): Promise<responses.ListSchedulerJobsResponse>;
    /**
     * Returns a list of Steps for an Activity Execution.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListStepsRequest
     * @return ListStepsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/ListSteps.ts.html |here} to see how to use ListSteps API.
     */
    listSteps(listStepsRequest: requests.ListStepsRequest): Promise<responses.ListStepsResponse>;
    /**
     * Manage execution actions for a Job like retrying or pausing a task.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ManageJobExecutionRequest
     * @return ManageJobExecutionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/ManageJobExecution.ts.html |here} to see how to use ManageJobExecution API.
     */
    manageJobExecution(manageJobExecutionRequest: requests.ManageJobExecutionRequest): Promise<responses.ManageJobExecutionResponse>;
    /**
     * Retrieve  aggregated summary information of ComplianceRecords within a Compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeComplianceRecordCountsRequest
     * @return SummarizeComplianceRecordCountsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/SummarizeComplianceRecordCounts.ts.html |here} to see how to use SummarizeComplianceRecordCounts API.
     */
    summarizeComplianceRecordCounts(summarizeComplianceRecordCountsRequest: requests.SummarizeComplianceRecordCountsRequest): Promise<responses.SummarizeComplianceRecordCountsResponse>;
    /**
     * Retrieve  aggregated summary information of Managed entities within a Compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeManagedEntityCountsRequest
     * @return SummarizeManagedEntityCountsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/SummarizeManagedEntityCounts.ts.html |here} to see how to use SummarizeManagedEntityCounts API.
     */
    summarizeManagedEntityCounts(summarizeManagedEntityCountsRequest: requests.SummarizeManagedEntityCountsRequest): Promise<responses.SummarizeManagedEntityCountsResponse>;
    /**
     * Retrieve aggregated summary information of Scheduler Jobs within a Compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeSchedulerJobCountsRequest
     * @return SummarizeSchedulerJobCountsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/SummarizeSchedulerJobCounts.ts.html |here} to see how to use SummarizeSchedulerJobCounts API.
     */
    summarizeSchedulerJobCounts(summarizeSchedulerJobCountsRequest: requests.SummarizeSchedulerJobCountsRequest): Promise<responses.SummarizeSchedulerJobCountsResponse>;
    /**
     * Updates the patch specified by the identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdatePatchRequest
     * @return UpdatePatchResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/UpdatePatch.ts.html |here} to see how to use UpdatePatch API.
     */
    updatePatch(updatePatchRequest: requests.UpdatePatchRequest): Promise<responses.UpdatePatchResponse>;
    /**
     * Update the details of a SchedulerDefinition that performs lifecycle management operations.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateSchedulerDefinitionRequest
     * @return UpdateSchedulerDefinitionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/UpdateSchedulerDefinition.ts.html |here} to see how to use UpdateSchedulerDefinition API.
     */
    updateSchedulerDefinition(updateSchedulerDefinitionRequest: requests.UpdateSchedulerDefinitionRequest): Promise<responses.UpdateSchedulerDefinitionResponse>;
    /**
     * Updates certain attributes for the specified schedule job.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateSchedulerJobRequest
     * @return UpdateSchedulerJobResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/UpdateSchedulerJob.ts.html |here} to see how to use UpdateSchedulerJob API.
     */
    updateSchedulerJob(updateSchedulerJobRequest: requests.UpdateSchedulerJobRequest): Promise<responses.UpdateSchedulerJobResponse>;
}
export declare enum FleetAppsManagementProvisionApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class FleetAppsManagementProvisionClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": FleetAppsManagementProvisionWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    protected _authProvider: common.AuthenticationDetailsProvider | undefined;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new FleetAppsManagementProvisionWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): FleetAppsManagementProvisionWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): FleetAppsManagementProvisionWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the provider if possible which in turn shuts down any associated circuit breaker
     */
    closeProvider(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Moves a Provision into a different compartment within the same tenancy. For information about moving resources between
     * compartments, see [Moving Resources to a Different Compartment](https://docs.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeProvisionCompartmentRequest
     * @return ChangeProvisionCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/ChangeProvisionCompartment.ts.html |here} to see how to use ChangeProvisionCompartment API.
     */
    changeProvisionCompartment(changeProvisionCompartmentRequest: requests.ChangeProvisionCompartmentRequest): Promise<responses.ChangeProvisionCompartmentResponse>;
    /**
     * Creates a Provision.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateProvisionRequest
     * @return CreateProvisionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/CreateProvision.ts.html |here} to see how to use CreateProvision API.
     */
    createProvision(createProvisionRequest: requests.CreateProvisionRequest): Promise<responses.CreateProvisionResponse>;
    /**
     * Deletes a Provision.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteProvisionRequest
     * @return DeleteProvisionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/DeleteProvision.ts.html |here} to see how to use DeleteProvision API.
     */
    deleteProvision(deleteProvisionRequest: requests.DeleteProvisionRequest): Promise<responses.DeleteProvisionResponse>;
    /**
     * Gets information about a Provision.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetProvisionRequest
     * @return GetProvisionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/GetProvision.ts.html |here} to see how to use GetProvision API.
     */
    getProvision(getProvisionRequest: requests.GetProvisionRequest): Promise<responses.GetProvisionResponse>;
    /**
     * Returns a list of all the Provisions in the specified compartment.
     * The query parameter `compartmentId` is required unless the query parameter `id` or `fleetId` is specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListProvisionsRequest
     * @return ListProvisionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/ListProvisions.ts.html |here} to see how to use ListProvisions API.
     */
    listProvisions(listProvisionsRequest: requests.ListProvisionsRequest): Promise<responses.ListProvisionsResponse>;
    /**
     * Updates a Provision.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateProvisionRequest
     * @return UpdateProvisionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/UpdateProvision.ts.html |here} to see how to use UpdateProvision API.
     */
    updateProvision(updateProvisionRequest: requests.UpdateProvisionRequest): Promise<responses.UpdateProvisionResponse>;
}
export declare enum FleetAppsManagementRunbooksApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class FleetAppsManagementRunbooksClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": FleetAppsManagementRunbooksWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    protected _authProvider: common.AuthenticationDetailsProvider | undefined;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new FleetAppsManagementRunbooksWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): FleetAppsManagementRunbooksWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): FleetAppsManagementRunbooksWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the provider if possible which in turn shuts down any associated circuit breaker
     */
    closeProvider(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Moves a Runbook into a different compartment within the same tenancy. For information about moving resources between
     * compartments, see [Moving Resources to a Different Compartment](https://docs.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeRunbookCompartmentRequest
     * @return ChangeRunbookCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/ChangeRunbookCompartment.ts.html |here} to see how to use ChangeRunbookCompartment API.
     */
    changeRunbookCompartment(changeRunbookCompartmentRequest: requests.ChangeRunbookCompartmentRequest): Promise<responses.ChangeRunbookCompartmentResponse>;
    /**
     * Moves a task record into a different compartment within the same tenancy. For information about moving resources between
     * compartments, see [Moving Resources to a Different Compartment](https://docs.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeTaskRecordCompartmentRequest
     * @return ChangeTaskRecordCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/ChangeTaskRecordCompartment.ts.html |here} to see how to use ChangeTaskRecordCompartment API.
     */
    changeTaskRecordCompartment(changeTaskRecordCompartmentRequest: requests.ChangeTaskRecordCompartmentRequest): Promise<responses.ChangeTaskRecordCompartmentResponse>;
    /**
     * Creates a runbook.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateRunbookRequest
     * @return CreateRunbookResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/CreateRunbook.ts.html |here} to see how to use CreateRunbook API.
     */
    createRunbook(createRunbookRequest: requests.CreateRunbookRequest): Promise<responses.CreateRunbookResponse>;
    /**
     * Add RunbookVersion in\u00A0Fleet Application Management.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateRunbookVersionRequest
     * @return CreateRunbookVersionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/CreateRunbookVersion.ts.html |here} to see how to use CreateRunbookVersion API.
     */
    createRunbookVersion(createRunbookVersionRequest: requests.CreateRunbookVersionRequest): Promise<responses.CreateRunbookVersionResponse>;
    /**
     * Creates a new task record.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateTaskRecordRequest
     * @return CreateTaskRecordResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/CreateTaskRecord.ts.html |here} to see how to use CreateTaskRecord API.
     */
    createTaskRecord(createTaskRecordRequest: requests.CreateTaskRecordRequest): Promise<responses.CreateTaskRecordResponse>;
    /**
     * Deletes a runbook specified by the identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteRunbookRequest
     * @return DeleteRunbookResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/DeleteRunbook.ts.html |here} to see how to use DeleteRunbook API.
     */
    deleteRunbook(deleteRunbookRequest: requests.DeleteRunbookRequest): Promise<responses.DeleteRunbookResponse>;
    /**
     * Removes a Runbook Version from the runbook in Fleet Application Management.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteRunbookVersionRequest
     * @return DeleteRunbookVersionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/DeleteRunbookVersion.ts.html |here} to see how to use DeleteRunbookVersion API.
     */
    deleteRunbookVersion(deleteRunbookVersionRequest: requests.DeleteRunbookVersionRequest): Promise<responses.DeleteRunbookVersionResponse>;
    /**
     * Deletes the task record specified by an identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteTaskRecordRequest
     * @return DeleteTaskRecordResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/DeleteTaskRecord.ts.html |here} to see how to use DeleteTaskRecord API.
     */
    deleteTaskRecord(deleteTaskRecordRequest: requests.DeleteTaskRecordRequest): Promise<responses.DeleteTaskRecordResponse>;
    /**
     * Get the details of a runbook in Fleet Application Management.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetRunbookRequest
     * @return GetRunbookResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/GetRunbook.ts.html |here} to see how to use GetRunbook API.
     */
    getRunbook(getRunbookRequest: requests.GetRunbookRequest): Promise<responses.GetRunbookResponse>;
    /**
     * Gets a Runbook Version by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetRunbookVersionRequest
     * @return GetRunbookVersionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/GetRunbookVersion.ts.html |here} to see how to use GetRunbookVersion API.
     */
    getRunbookVersion(getRunbookVersionRequest: requests.GetRunbookVersionRequest): Promise<responses.GetRunbookVersionResponse>;
    /**
     * Gets information for the specified task record.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetTaskRecordRequest
     * @return GetTaskRecordResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/GetTaskRecord.ts.html |here} to see how to use GetTaskRecord API.
     */
    getTaskRecord(getTaskRecordRequest: requests.GetTaskRecordRequest): Promise<responses.GetTaskRecordResponse>;
    /**
     * List versions for a runbook in Fleet Application Management.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListRunbookVersionsRequest
     * @return ListRunbookVersionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/ListRunbookVersions.ts.html |here} to see how to use ListRunbookVersions API.
     */
    listRunbookVersions(listRunbookVersionsRequest: requests.ListRunbookVersionsRequest): Promise<responses.ListRunbookVersionsResponse>;
    /**
     * Returns a list of all the runbooks in the specified compartment.
     * The query parameter `compartmentId` is required unless the query parameter `id` is specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListRunbooksRequest
     * @return ListRunbooksResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/ListRunbooks.ts.html |here} to see how to use ListRunbooks API.
     */
    listRunbooks(listRunbooksRequest: requests.ListRunbooksRequest): Promise<responses.ListRunbooksResponse>;
    /**
     * Returns a list of all the task records in the specified compartment.
     * The query parameter `compartmentId` is required unless the query parameter `id` is specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListTaskRecordsRequest
     * @return ListTaskRecordsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/ListTaskRecords.ts.html |here} to see how to use ListTaskRecords API.
     */
    listTaskRecords(listTaskRecordsRequest: requests.ListTaskRecordsRequest): Promise<responses.ListTaskRecordsResponse>;
    /**
     * Publish the specified version of the runbook.
     * The specified version of the runbook becomes acitve when it is published.Only active versions of runbook can be used in execution.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param PublishRunbookRequest
     * @return PublishRunbookResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/PublishRunbook.ts.html |here} to see how to use PublishRunbook API.
     */
    publishRunbook(publishRunbookRequest: requests.PublishRunbookRequest): Promise<responses.PublishRunbookResponse>;
    /**
     * Set a runbook as default.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SetDefaultRunbookRequest
     * @return SetDefaultRunbookResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/SetDefaultRunbook.ts.html |here} to see how to use SetDefaultRunbook API.
     */
    setDefaultRunbook(setDefaultRunbookRequest: requests.SetDefaultRunbookRequest): Promise<responses.SetDefaultRunbookResponse>;
    /**
     * Updates the runbook specified by the identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateRunbookRequest
     * @return UpdateRunbookResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/UpdateRunbook.ts.html |here} to see how to use UpdateRunbook API.
     */
    updateRunbook(updateRunbookRequest: requests.UpdateRunbookRequest): Promise<responses.UpdateRunbookResponse>;
    /**
     * Updates the RunbookVersion.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateRunbookVersionRequest
     * @return UpdateRunbookVersionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/UpdateRunbookVersion.ts.html |here} to see how to use UpdateRunbookVersion API.
     */
    updateRunbookVersion(updateRunbookVersionRequest: requests.UpdateRunbookVersionRequest): Promise<responses.UpdateRunbookVersionResponse>;
    /**
     * Updates certain attributes for the specified task record.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateTaskRecordRequest
     * @return UpdateTaskRecordResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/UpdateTaskRecord.ts.html |here} to see how to use UpdateTaskRecord API.
     */
    updateTaskRecord(updateTaskRecordRequest: requests.UpdateTaskRecordRequest): Promise<responses.UpdateTaskRecordResponse>;
}
export declare enum FleetAppsManagementWorkRequestApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class FleetAppsManagementWorkRequestClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": FleetAppsManagementWorkRequestWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    protected _authProvider: common.AuthenticationDetailsProvider | undefined;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new FleetAppsManagementWorkRequestWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): FleetAppsManagementWorkRequestWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): FleetAppsManagementWorkRequestWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the provider if possible which in turn shuts down any associated circuit breaker
     */
    closeProvider(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Gets details of the work request with the given ID.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetWorkRequestRequest
     * @return GetWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/GetWorkRequest.ts.html |here} to see how to use GetWorkRequest API.
     */
    getWorkRequest(getWorkRequestRequest: requests.GetWorkRequestRequest): Promise<responses.GetWorkRequestResponse>;
    /**
     * Returns a (paginated) list of errors for the work request with the given ID.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestErrorsRequest
     * @return ListWorkRequestErrorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/ListWorkRequestErrors.ts.html |here} to see how to use ListWorkRequestErrors API.
     */
    listWorkRequestErrors(listWorkRequestErrorsRequest: requests.ListWorkRequestErrorsRequest): Promise<responses.ListWorkRequestErrorsResponse>;
    /**
     * Returns a (paginated) list of logs for the work request with the given ID.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestLogsRequest
     * @return ListWorkRequestLogsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/ListWorkRequestLogs.ts.html |here} to see how to use ListWorkRequestLogs API.
     */
    listWorkRequestLogs(listWorkRequestLogsRequest: requests.ListWorkRequestLogsRequest): Promise<responses.ListWorkRequestLogsResponse>;
    /**
     * Lists the work requests in a compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestsRequest
     * @return ListWorkRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/fleetappsmanagement/ListWorkRequests.ts.html |here} to see how to use ListWorkRequests API.
     */
    listWorkRequests(listWorkRequestsRequest: requests.ListWorkRequestsRequest): Promise<responses.ListWorkRequestsResponse>;
}
export {};
