/**
 * Fleet Application Management Service API
 * Fleet Application Management provides a centralized platform to help you automate resource management tasks, validate patch compliance, and enhance operational efficiency across an enterprise.

 * OpenAPI spec version: 20250228
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2025, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * Summary of the Scheduler Executions.
 */
export interface SchedulerExecutionSummary {
    /**
     * The OCID of the resource.
     */
    "id": string;
    /**
      * A user-friendly name. Does not have to be unique, and it's changeable.
  * Avoid entering confidential information.
  * <p>
  Example: {@code My new resource}
  *
      */
    "displayName": string;
    /**
     * Compartment OCID
     */
    "compartmentId": string;
    /**
     * The time this resource was created. An RFC3339 formatted datetime string.
     */
    "timeCreated": Date;
    /**
     * The time this resource was last updated. An RFC3339 formatted datetime string.
     */
    "timeUpdated"?: Date;
    /**
     * The scheduled date and time for the Job.
     */
    "timeScheduled"?: Date;
    /**
     * Action Group associated with the Schedule.
     */
    "activityId"?: string;
    /**
     * ResourceId associated with the Schedule.
     */
    "resourceId"?: string;
    /**
     * jobId associated with the Schedule.
     */
    "schedulerJobId"?: string;
    /**
     * Resource DsiplayName associated with the Schedule.
     */
    "resourceDisplayName"?: string;
    /**
     * RunbookId associated with the Schedule.
     */
    "runbookId"?: string;
    /**
     * Name of the Runbook version associated with the Schedule.
     */
    "runbookVersionName"?: string;
    /**
     * DsiplayName of Runbook associated with the Schedule.
     */
    "runbookDisplayName"?: string;
    /**
     * Latest Runbook version available.
     */
    "latestRunbookVersionName"?: string;
    "schedulerDefinition"?: model.AssociatedSchedulerDefinition;
    /**
     * Actual start date and time for the Execution.
     */
    "timeStarted"?: Date;
    /**
     * Actual end date and time for the Execution.
     */
    "timeEnded"?: Date;
    /**
     * The current state of the Scheduler Execution.
     */
    "lifecycleState": SchedulerExecutionSummary.LifecycleState;
    /**
     * A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
     */
    "lifecycleDetails"?: string;
    /**
     * Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
     * Example: {@code {\"bar-key\": \"value\"}}
     *
     */
    "freeformTags": {
        [key: string]: string;
    };
    /**
     * Defined tags for this resource. Each key is predefined and scoped to a namespace.
     * Example: {@code {\"foo-namespace\": {\"bar-key\": \"value\"}}}
     *
     */
    "definedTags": {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
     * System tags for this resource. Each key is predefined and scoped to a namespace.
     * Example: {@code {\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}}
     *
     */
    "systemTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
}
export declare namespace SchedulerExecutionSummary {
    enum LifecycleState {
        Active = "ACTIVE",
        Deleted = "DELETED",
        Failed = "FAILED",
        Inactive = "INACTIVE",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: SchedulerExecutionSummary): object;
    function getDeserializedJsonObj(obj: SchedulerExecutionSummary): object;
}
