/**
 * GoldenGate API
 * Use the Oracle Cloud Infrastructure GoldenGate APIs to perform data replication operations.

 * OpenAPI spec version: 20200407
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2025, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * The information about a new Oracle NoSQL Connection.
 *
 */
export interface CreateOracleNosqlConnectionDetails extends model.CreateConnectionDetails {
    /**
     * The Oracle NoSQL technology type.
     */
    "technologyType": string;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the related OCI tenancy.
     *
     */
    "tenancyId"?: string;
    /**
     * The name of the region. e.g.: us-ashburn-1
     * If the region is not provided, backend will default to the default region.
     *
     */
    "region"?: string;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the OCI user who will access the Oracle NoSQL database.
     * The user must have write access to the table they want to connect to.
     * If the user is not provided, backend will default to the user who is calling the API endpoint.
     *
     */
    "userId"?: string;
    /**
     * The base64 encoded content of the private key file (PEM file) corresponding to the API key of the fingerprint.
     * See documentation: https://docs.oracle.com/en-us/iaas/Content/Identity/Tasks/managingcredentials.htm
     * Deprecated: This field is deprecated and replaced by \"privateKeyFileSecretId\". This field will be removed after February 15 2026.
     *
     */
    "privateKeyFile"?: string;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Secret that stores the content of the private key file (PEM file) corresponding to the API key of the fingerprint.
     * See documentation: https://docs.oracle.com/en-us/iaas/Content/Identity/Tasks/managingcredentials.htm
     * Note: When provided, 'privateKeyFile' field must not be provided.
     *
     */
    "privateKeyFileSecretId"?: string;
    /**
     * The passphrase of the private key.
     * Deprecated: This field is deprecated and replaced by \"privateKeyPassphraseSecretId\". This field will be removed after February 15 2026.
     *
     */
    "privateKeyPassphrase"?: string;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Secret that stores the passphrase of the private key.
     * Note: When provided, 'privateKeyPassphrase' field must not be provided.
     *
     */
    "privateKeyPassphraseSecretId"?: string;
    /**
     * The fingerprint of the API Key of the user specified by the userId.
     * See documentation: https://docs.oracle.com/en-us/iaas/Content/Identity/Tasks/managingcredentials.htm
     *
     */
    "publicKeyFingerprint"?: string;
    /**
     * Indicates that the user intents to connect to the instance through resource principal.
     *
     */
    "shouldUseResourcePrincipal"?: boolean;
    "connectionType": string;
}
export declare namespace CreateOracleNosqlConnectionDetails {
    function getJsonObj(obj: CreateOracleNosqlConnectionDetails, isParentJsonObj?: boolean): object;
    const connectionType = "ORACLE_NOSQL";
    function getDeserializedJsonObj(obj: CreateOracleNosqlConnectionDetails, isParentJsonObj?: boolean): object;
}
