/**
 * File Storage with Lustre API
 * Use the File Storage with Lustre API to manage Lustre file systems and related resources. For more information, see [File Storage with Lustre](https://docs.oracle.com/iaas/Content/lustre/home.htm).
 * OpenAPI spec version: 20250228
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2025, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * The details to create a Lustre file system.
 */
export interface CreateLustreFileSystemDetails {
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment that contains the Lustre file system.
     */
    "compartmentId": string;
    /**
      * The availability domain the file system is in. May be unset
  * as a blank or NULL value.
  * <p>
  Example: {@code Uocm:PHX-AD-1}
  *
      */
    "availabilityDomain": string;
    /**
      * A user-friendly name. It does not have to be unique, and it is changeable.
  * Avoid entering confidential information.
  * <p>
  Example: {@code My Lustre file system}
  *
      */
    "displayName"?: string;
    /**
     * Short description of the Lustre file system.
     * Avoid entering confidential information.
     *
     */
    "fileSystemDescription"?: string;
    /**
      * Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
  * For more information, see [Resource Tags](https://docs.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
  * <p>
  Example: {@code {\"Department\": \"Finance\"}}
  *
      */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
      * Defined tags for this resource. Each key is predefined and scoped to a namespace.
  * For more information, see [Resource Tags](https://docs.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
  * <p>
  Example: {@code {\"Operations\": {\"CostCenter\": \"42\"}}}
  *
      */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
     * A list of Network Security Group [OCIDs](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) associated with this lustre file system.
     * A maximum of 5 is allowed.
     * Setting this to an empty array after the list is created removes the lustre file system from all NSGs.
     * For more information about NSGs, see [Security Rules](https://docs.oracle.com/iaas/Content/Network/Concepts/securityrules.htm).
     *
     */
    "nsgIds"?: Array<string>;
    /**
     * The Lustre file system name. This is used in mount commands and other aspects of the client command line interface.
     * The file system name is limited to 8 characters. Allowed characters are lower and upper case English letters, numbers, and '_'.
     * If you have multiple Lustre file systems mounted on the same clients, this name can help distinguish them.
     *
     */
    "fileSystemName": string;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the KMS key used to encrypt the encryption keys associated with this file system.
     *
     */
    "kmsKeyId"?: string;
    /**
     * Capacity of the Lustre file system in GB. You can increase capacity only in multiples of 5 TB. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "capacityInGBs": number;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the subnet the Lustre file system is in.
     */
    "subnetId": string;
    /**
     * The Lustre file system performance tier. A value of {@code MBPS_PER_TB_125} represents 125 megabytes per second per terabyte.
     */
    "performanceTier": CreateLustreFileSystemDetails.PerformanceTier;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the cluster placement group in which the Lustre file system exists.
     */
    "clusterPlacementGroupId"?: string;
    "rootSquashConfiguration": model.RootSquashConfiguration;
}
export declare namespace CreateLustreFileSystemDetails {
    enum PerformanceTier {
        MbpsPerTb125 = "MBPS_PER_TB_125",
        MbpsPerTb250 = "MBPS_PER_TB_250",
        MbpsPerTb500 = "MBPS_PER_TB_500",
        MbpsPerTb1000 = "MBPS_PER_TB_1000"
    }
    function getJsonObj(obj: CreateLustreFileSystemDetails): object;
    function getDeserializedJsonObj(obj: CreateLustreFileSystemDetails): object;
}
